@@ -1,8 +1,6 @@
 """ NWP Data Source """
 import logging
-from concurrent import futures
 from dataclasses import InitVar, dataclass
-from numbers import Number
 from typing import Iterable, Optional
 
 import numpy as np
@@ -10,10 +8,8 @@ import pandas as pd
 import xarray as xr
 
 from nowcasting_dataset import utils
-from nowcasting_dataset.data_sources.data_source import ZarrDataSource
-from nowcasting_dataset.data_sources.nwp.nwp_model import NWP
-from nowcasting_dataset.dataset.xr_utils import join_list_data_array_to_batch_dataset
 from nowcasting_dataset.consts import NWP_VARIABLE_NAMES
+from nowcasting_dataset.data_sources.data_source import ZarrDataSource
 
 _LOG = logging.getLogger(__name__)
 
@@ -43,7 +39,6 @@ class NWPDataSource(ZarrDataSource):
             hcc   : High-level cloud cover in %.
     """
 
-    zarr_path: str = None
     channels: Optional[Iterable[str]] = NWP_VARIABLE_NAMES
     image_size_pixels: InitVar[int] = 2
     meters_per_pixel: InitVar[int] = 2_000
@@ -78,69 +73,6 @@ class NWPDataSource(ZarrDataSource):
         data = self._open_data()
         self._data = data["UKV"].sel(variable=list(self.channels))
 
-    def get_batch(
-        self,
-        t0_datetimes: pd.DatetimeIndex,
-        x_locations: Iterable[Number],
-        y_locations: Iterable[Number],
-    ) -> NWP:
-        """
-        Get batch data
-
-        Args:
-            t0_datetimes: list of timstamps
-            x_locations: list of x locations, where the batch data is for
-            y_locations: list of y locations, where the batch data is for
-
-        Returns: batch data
-
-        """
-        # Lazily select time slices.
-        selections = []
-        for t0_dt in t0_datetimes[: self.n_timesteps_per_batch]:
-            selections.append(self._get_time_slice(t0_dt))
-
-        # Load entire time slices from disk in multiple threads.
-        data = []
-        with futures.ThreadPoolExecutor(max_workers=self.n_timesteps_per_batch) as executor:
-            data_futures = []
-            # Submit tasks.
-            for selection in selections:
-                future = executor.submit(selection.load)
-                data_futures.append(future)
-
-            # Grab tasks
-            for future in data_futures:
-                d = future.result()
-                data.append(d)
-
-        # Select squares from pre-loaded time slices.
-        examples = []
-        for i, (x_meters_center, y_meters_center) in enumerate(zip(x_locations, y_locations)):
-            selected_data = data[i % self.n_timesteps_per_batch]
-            bounding_box = self._square.bounding_box_centered_on(
-                x_meters_center=x_meters_center, y_meters_center=y_meters_center
-            )
-            selected_data = selected_data.sel(
-                x=slice(bounding_box.left, bounding_box.right),
-                y=slice(bounding_box.top, bounding_box.bottom),
-            )
-
-            # selected_sat_data is likely to have 1 too many pixels in x and y
-            # because sel(x=slice(a, b)) is [a, b], not [a, b).  So trim:
-            selected_data = selected_data.isel(
-                x=slice(0, self._square.size_pixels), y=slice(0, self._square.size_pixels)
-            )
-
-            t0_dt = t0_datetimes[i]
-            selected_data = self._post_process_example(selected_data, t0_dt)
-
-            examples.append(selected_data)
-
-        output = join_list_data_array_to_batch_dataset(examples)
-
-        return NWP(output)
-
     def _open_data(self) -> xr.DataArray:
         return open_nwp(self.zarr_path, consolidated=self.consolidated)
 
@@ -150,8 +82,7 @@ class NWPDataSource(ZarrDataSource):
 
         Note that this function does *not* resample from hourly to 5 minutely.
         Resampling would be very expensive if done on the whole geographical
-        extent of the NWP data!  So resampling is done in
-        _post_process_example().
+        extent of the NWP data!
 
         Args:
             t0_dt: the time slice is around t0_dt.
@@ -186,9 +117,7 @@ class NWPDataSource(ZarrDataSource):
         selected_data = selected_data.resample({"target_time": "5T"})
         selected_data = selected_data.interpolate()
         selected_data = selected_data.sel(target_time=slice(start_dt, end_dt))
-        selected_data = selected_data.rename({"target_time": "time"})
-        selected_data = selected_data.rename({"variable": "channels"})
-
+        selected_data = selected_data.rename({"target_time": "time", "variable": "channels"})
         selected_data.data = selected_data.data.astype(np.float32)
 
         return selected_data
